Matter data objects
===================

Some of the important classes in the matter package are Atom, Lattice, and Structure:





Here is the complete API to Atom:


:mod:`matter.Atom`
------------------

.. automodule:: matter.Atom
   :members:
   :undoc-members:
   :show-inheritance:
   
   
Here is the complete API to Lattice:


:mod:`matter.Lattice`
---------------------

.. automodule:: matter.Lattice
   :members:
   :undoc-members:
   :show-inheritance:
   
   
Here is the complete API to Structure:


:mod:`matter.Structure`
-----------------------

.. automodule:: matter.Structure
   :members:
   :undoc-members:
   :show-inheritance: